.. _developer_guidelines:

Development guidelines
------------------------------

Guidelines for developers to contribute to ECMWF software are explained in our
`Codex <https://github.com/ecmwf/codex/blob/main/Guidelines/External-Contributions.md>`_.
